@@ -20,7 +20,6 @@ import os
 import openslide
 import PIL
 import tifftools
-from pkg_resources import DistributionNotFound, get_distribution
 
 from large_image.cache_util import LruCacheMetaclass, methodcache
 from large_image.constants import TILE_FORMAT_PIL, SourcePriority
@@ -34,8 +33,14 @@ except ImportError:
 
 
 try:
-    __version__ = get_distribution(__name__).version
-except DistributionNotFound:
+    from importlib.metadata import PackageNotFoundError
+    from importlib.metadata import version as _importlib_version
+except ImportError:
+    from importlib_metadata import PackageNotFoundError
+    from importlib_metadata import version as _importlib_version
+try:
+    __version__ = _importlib_version(__name__)
+except PackageNotFoundError:
     # package is not installed
     pass
 
@@ -47,7 +52,7 @@ class OpenslideFileTileSource(FileTileSource, metaclass=LruCacheMetaclass):
     """
 
     cacheName = 'tilesource'
-    name = 'openslidefile'
+    name = 'openslide'
     extensions = {
         None: SourcePriority.MEDIUM,
         'bif': SourcePriority.LOW,  # Ventana
@@ -77,7 +82,7 @@ class OpenslideFileTileSource(FileTileSource, metaclass=LruCacheMetaclass):
         """
         super().__init__(path, **kwargs)
 
-        self._largeImagePath = self._getLargeImagePath()
+        self._largeImagePath = str(self._getLargeImagePath())
 
         try:
             self._openslide = openslide.OpenSlide(self._largeImagePath)
@@ -293,7 +298,7 @@ class OpenslideFileTileSource(FileTileSource, metaclass=LruCacheMetaclass):
         # Always scale to the svs level 0 tile size.
         if svslevel['scale'] != 1:
             tile = tile.resize((self.tileWidth, self.tileHeight),
-                               PIL.Image.LANCZOS)
+                               getattr(PIL.Image, 'Resampling', PIL.Image).LANCZOS)
         return self._outputTile(tile, TILE_FORMAT_PIL, x, y, z, pilImageAllowed,
                                 numpyAllowed, **kwargs)
 
@@ -367,7 +372,7 @@ class OpenslideFileTileSource(FileTileSource, metaclass=LruCacheMetaclass):
                 return None
         bytePath = self._largeImagePath
         if not isinstance(bytePath, bytes):
-            bytePath = bytePath.encode('utf8')
+            bytePath = bytePath.encode()
         _tiffFile = libtiff_ctypes.TIFF.open(bytePath)
         _tiffFile.SetDirectory(images[imageKey])
         img = _tiffFile.read_image()
